---
title: "Urubu 1.3.0 released"
layout: page 
date: 2016-11-14
---

Highlights:

* Add posibility to override output filename. (#51). See the `saveas` attribute
in the [manual][/manual/structure#Content Files].
An example usage, see [/faq/sitemap].

* The `urubu serve` command is more secure.  This is transparent to the user
(#49).

* Added option for jinja2 to fail on undefined vars (#47). 
See the `strict_undefined` attribute in the [manual][/manual/structure#_siteyml].

